==> pygeometa-0.6.0.tar.gz: pygeometa-0.6.0/pygeometa/schemas/base.py <==
# =================================================================
#
# Terms and Conditions of Use
#
# Unless otherwise noted, computer program source code of this
# distribution # is covered under Crown Copyright, Government of
# Canada, and is distributed under the MIT License.
#
# The Canada wordmark and related graphics associated with this
# distribution are protected under trademark law and copyright law.
# No permission is granted to use them outside the parameters of
# the Government of Canada's corporate identity program. For
# more information, see
# http://www.tbs-sct.gc.ca/fip-pcim/index-eng.asp
#
# Copyright title to all 3rd party software distributed with this
# software is held by the respective copyright holders as noted in
# those files. Users are asked to read the 3rd Party Licenses
# referenced with those assets.
#
# Copyright (c) 2020 Tom Kralidis
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
#
# =================================================================

import os

from pygeometa import core

TEMPLATES = os.path.dirname(os.path.realpath(__file__))


class BaseOutputSchema:
    """generic OutputSchema ABC"""

    def __init__(self, name: str = None, outputformat: str = None,
                 template_dir: str = None):
        """
        Initialize object

        :param name: name of output schema
        :param outputformat: output format (XML, JSON)

        :returns: pygeometa.schemas.base.BaseOutputSchema
        """

        self.name = name
        self.outputformat = outputformat
        self.template_dir = template_dir

    def write(self, mcf: dict) -> str:
        """
        Write outputschema to string buffer

        :param mcf: dict of MCF content model

        :returns: str of metadata in outputschema representation
        """

        return core.render_j2_template(mcf, template_dir=self.template_dir)

    def __repr__(self):
        return '<{}OutputSchema> {}'.format(self.name.upper(), self.name)

==> pygeometa-0.8.0.tar.gz: pygeometa-0.8.0/pygeometa/schemas/base.py <==
# =================================================================
#
# Terms and Conditions of Use
#
# Unless otherwise noted, computer program source code of this
# distribution # is covered under Crown Copyright, Government of
# Canada, and is distributed under the MIT License.
#
# The Canada wordmark and related graphics associated with this
# distribution are protected under trademark law and copyright law.
# No permission is granted to use them outside the parameters of
# the Government of Canada's corporate identity program. For
# more information, see
# http://www.tbs-sct.gc.ca/fip-pcim/index-eng.asp
#
# Copyright title to all 3rd party software distributed with this
# software is held by the respective copyright holders as noted in
# those files. Users are asked to read the 3rd Party Licenses
# referenced with those assets.
#
# Copyright (c) 2020 Tom Kralidis
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
#
# =================================================================

import os

from pygeometa import core

TEMPLATES = os.path.dirname(os.path.realpath(__file__))


class BaseOutputSchema:
    """generic OutputSchema ABC"""

    def __init__(self, name: str = None, outputformat: str = None,
                 template_dir: str = None):
        """
        Initialize object

        :param name: name of output schema
        :param outputformat: output format (XML, JSON)

        :returns: pygeometa.schemas.base.BaseOutputSchema
        """

        self.name = name
        self.outputformat = outputformat
        self.template_dir = template_dir

    def write(self, mcf: dict, stringify: str = True) -> str:
        """
        Write outputschema to string buffer

        :param mcf: dict of MCF content model
        :param stringify: whether to return a string representation (default)
                          else native (dict, etree)

        :returns: str of metadata in outputschema representation
        """

        return core.render_j2_template(mcf, template_dir=self.template_dir)

    def __repr__(self):
        return '<{}OutputSchema> {}'.format(self.name.upper(), self.name)
